| CI           | [![GitHub Workflow Status][github-ci-badge]][github-ci-link] [![GitHub Workflow Status][github-upstream-ci-badge]][github-upstream-ci-link] [![Code Coverage Status][codecov-badge]][codecov-link] [![asv-badge]][asv-link] |
| :----------- | :----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| **Docs**     |                                                                    [![Documentation Status][rtd-badge]][rtd-link]                                                                    |
| **Package**  |                            [![Conda][conda-badge]][conda-link] [![PyPI][pypi-badge]][pypi-link] [![Python Version][python-version-badge]][python-version-badge-link]                 |
| **License**  |                                                                        [![License][license-badge]][repo-link]                                                                        |
| **Citing**  |                                                                              [![DOI][doi-badge]][doi-link]                                                                            |



GeoCAT-comp is the computational component of the
[GeoCAT](https://geocat.ucar.edu/) project. GeoCAT-comp provides computational
functions for operating on geosciences data. Many of these functions originated
in NCL and were translated into Python in GeoCAT-comp; however, developers are
welcome to suggest novel computational functions for geosciences data.


# Documentation

[GeoCAT Homepage](https://geocat.ucar.edu/)

[GeoCAT Contributor's Guide](https://github.com/NCAR/geocat-comp/blob/main/CONTRIBUTING.md)

[GeoCAT-comp documentation on Read the Docs](https://geocat-comp.readthedocs.io)


# Installation and build instructions

Please see our documentation for
[installation and build instructions](https://github.com/NCAR/geocat-comp/blob/main/INSTALLATION.md).


# Citing GeoCAT-comp

If you use this software, please cite it as described at the [GeoCAT-comp - Citation](
https://geocat-comp.readthedocs.io/en/latest/citation.html) page.


[github-ci-badge]: https://img.shields.io/github/actions/workflow/status/NCAR/geocat-comp/ci.yml?branch=main&label=CI&style=for-the-badge
[github-ci-link]: https://github.com/NCAR/geocat-comp/actions/workflows/ci.yml
[github-upstream-ci-badge]: https://img.shields.io/github/actions/workflow/status/NCAR/geocat-comp/upstream-dev-ci.yml?branch=main&label=Upstream%20CI&style=for-the-badge
[github-upstream-ci-link]: https://github.com/NCAR/geocat-comp/actions/workflows/upstream-dev-ci.yml
[codecov-badge]: https://img.shields.io/codecov/c/github/NCAR/geocat-comp.svg?logo=codecov&style=for-the-badge&color=brightgreen
[codecov-link]: https://codecov.io/gh/NCAR/geocat-comp/coverage.yml
[asv-badge]: https://img.shields.io/badge/benchmarked%20by-asv-green.svg?style=for-the-badge
[asv-link]: https://ncar.github.io/geocat-comp-asv/
[rtd-badge]: https://img.shields.io/readthedocs/geocat-comp/latest.svg?style=for-the-badge
[rtd-link]: https://geocat-comp.readthedocs.io/en/latest/?badge=latest
[pypi-badge]: https://img.shields.io/pypi/v/geocat-comp?logo=pypi&style=for-the-badge
[pypi-link]: https://pypi.org/project/geocat-comp
[python-version-badge]: https://img.shields.io/pypi/pyversions/geocat-comp?style=for-the-badge
[python-version-badge-link]: https://img.shields.io/pypi/pyversions/geocat-comp
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/geocat-comp?logo=anaconda&style=for-the-badge
[conda-link]: https://anaconda.org/conda-forge/geocat-comp
[license-badge]: https://img.shields.io/github/license/NCAR/geocat-comp?style=for-the-badge
[comment]: <> ([doi-badge]: https://img.shields.io/badge/DOI-10.5065%2Fa8pp--4358-brightgreen?style=for-the-badge)
[comment]: <> ([doi-link]: https://doi.org/10.5065/a8pp-4358)
[doi-badge]: https://zenodo.org/badge/DOI/10.5281/zenodo.6607205.svg
[doi-link]: https://doi.org/10.5281/zenodo.6607205
[repo-link]: https://github.com/NCAR/geocat-comp
